;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "time-zones" "20251103.936"
  "Time zone lookups."
  '((emacs "28.1"))
  :url "https://github.com/xenodium/time-zones"
  :commit "23c866db6a3aecac5e860cda6010d9afc847e5c6"
  :revdesc "23c866db6a3a")
